@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_boilerplate2.py 12436 2020-07-30 08:41:42Z Lavender $
+# $Id: build_boilerplate2.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2020-07-30 16:41:42 +0800 (週四, 30 七月 2020) $
-# $Revision: 12436 $
+# $Author: Mint $
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 
 import os
 import re
@@ -88,7 +88,7 @@ COMMENT = "The template was modified by Nuwainfo.com"
 LEGEL = "\n%s\n" % get_template('boilerplate/txt/Legel.txt').render()
 
 # cms --------------------------------------------------------------------------
-CMS_HEAD_FRONT_TAG = ("{% load cms_tags menu_tags sekizai_tags staticfiles %}"
+CMS_HEAD_FRONT_TAG = ("{% load cms_tags menu_tags sekizai_tags static %}"
                       "{% with '' as CMS_STATIC_PREFIX %}{% with '/' as CMS_LINK_PREFIX %}")
 CMS_HEAD_BACK_TAG = "{% endwith %}{% endwith %}{% render_block 'css' %}"
 
