@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_templates.py 11436 2019-04-10 17:56:15Z Lavender $
+# $Id: build_templates.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2019-04-11 01:56:15 +0800 (Thu, 11 Apr 2019) $
-# $Revision: 11436 $
+# $Author: Mint $
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 
 import os
 import sys
@@ -118,16 +118,10 @@ class Command(BaseCommand):
                 continue
 
             # dumpdata
-            if not cms.__version__.startswith('3.4'):
-                error = os.system(
-                    ("%s manage.py cms_dumpdata "
-                     "fixtures/initial_data.json -n") % 
-                    (sys.executable,))
-            else:
-                error = os.system(
-                    ("%s manage.py dumpdata cms djangocms_text_ckeditor "
-	                 "cmsplugin_filer_image > fixtures/initial_data.json") %
-                    (sys.executable,))
+            error = os.system(
+                ("%s manage.py cms_dumpdata "
+                 "fixtures/initial_data.json -n") % 
+                (sys.executable,))
 
             if not error == 0:
                 logger.error(
