@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 11946 2020-02-22 13:22:03Z Trista $
+# $Id: urls.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,11 +11,12 @@
 # See the License for the specific language governing permissions and 
 # limitations under the License.
 #
-# $Author: Trista $
-# $Date: 2020-02-22 21:22:03 +0800 (Sat, 22 Feb 2020) $
-# $Revision: 11946 $ 
+# $Author: Mint $
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $ 
 
 from django.conf.urls import url
+from django.urls import include
 
 from . import views
 
